@@ -1,6 +1,6 @@
 from .category import CategoricalEncoder
+from .custom import CustomTransformer
 from .event import EventEncoder
 from .id import IDEncoder
 from .number import NumericalEncoder
 from .sequence import Sequencer
-from .target import TargetTransformer
